pub struct ArrayOfTables { /* private fields */ }Expand description
A top-level sequence of Tables, each under their own header
Implementations
Sourceimpl ArrayOfTables
Constructors
impl ArrayOfTables
Constructors
See also FromIterator
Sourceimpl ArrayOfTables
Formatting
impl ArrayOfTables
Formatting
Sourceimpl ArrayOfTables
impl ArrayOfTables
Sourcepub fn iter(&self) -> ArrayOfTablesIter<'_>
pub fn iter(&self) -> ArrayOfTablesIter<'_>
Returns an iterator over tables.
Sourcepub fn iter_mut(&mut self) -> ArrayOfTablesIterMut<'_>
pub fn iter_mut(&mut self) -> ArrayOfTablesIterMut<'_>
Returns an iterator over tables.
Sourcepub fn len(&self) -> usize
pub fn len(&self) -> usize
Returns the length of the underlying Vec.
To get the actual number of items use a.iter().count().
Sourcepub fn get_mut(&mut self, index: usize) -> Option<&mut Table>
pub fn get_mut(&mut self, index: usize) -> Option<&mut Table>
Returns an optional mutable reference to the table.
Sourcepub fn insert(&mut self, index: usize, table: Table)
pub fn insert(&mut self, index: usize, table: Table)
Inserts a table at the given index within the array, shifting all tables after it to the right.
Panics
Panics if index > len.
Sourcepub fn replace(&mut self, index: usize, table: Table) -> Table
pub fn replace(&mut self, index: usize, table: Table) -> Table
Replaces a table at the given index within the array, returning the old table.
Panics
Panics if index >= len.
Examples
use toml_edit::{ArrayOfTables, Table, value};
let mut arr = ArrayOfTables::new();
arr.push(Table::from_iter([("name", value("apple"))]));
arr.replace(0, Table::from_iter([("name", value("banana"))]));Sourcepub fn retain<F>(&mut self, keep: F)
pub fn retain<F>(&mut self, keep: F)
Retains only the elements specified by the keep predicate.
In other words, remove all tables for which keep(&table) returns false.
This method operates in place, visiting each element exactly once in the original order, and preserves the order of the retained elements.